@@ -1,5 +1,5 @@
 // Copyright (c) HashiCorp, Inc.
-// SPDX-License-Identifier: MPL-2.0
+// SPDX-License-Identifier: BUSL-1.1
 
 package github
 
@@ -14,11 +14,14 @@ import (
 	"log"
 	"net/http"
 	"os"
+	"path"
 	"path/filepath"
 	"strings"
 
-	"github.com/google/go-github/v33/github"
 	plugingetter "github.com/hashicorp/packer/packer/plugin-getter"
+
+	"github.com/google/go-github/v33/github"
+	"github.com/hashicorp/packer/hcl2template/addrs"
 	"golang.org/x/oauth2"
 )
 
@@ -31,11 +34,21 @@ const (
 type Getter struct {
 	Client    *github.Client
 	UserAgent string
+	Name      string
 }
 
 var _ plugingetter.Getter = &Getter{}
 
-func transformChecksumStream() func(in io.ReadCloser) (io.ReadCloser, error) {
+type PluginMetadata struct {
+	Versions map[string]PluginVersion `json:"versions"`
+}
+
+type PluginVersion struct {
+	Name    string `json:"name"`
+	Version string `json:"version"`
+}
+
+func TransformChecksumStream() func(in io.ReadCloser) (io.ReadCloser, error) {
 	return func(in io.ReadCloser) (io.ReadCloser, error) {
 		defer in.Close()
 		rd := bufio.NewReader(in)
@@ -156,10 +169,45 @@ func (t *HostSpecificTokenAuthTransport) base() http.RoundTripper {
 	return http.DefaultTransport
 }
 
+type GithubPlugin struct {
+	Hostname  string
+	Namespace string
+	Type      string
+}
+
+func NewGithubPlugin(source *addrs.Plugin) (*GithubPlugin, error) {
+	parts := source.Parts()
+	if len(parts) != 3 {
+		return nil, fmt.Errorf("Invalid github.com URI %q: a Github-compatible source must be in the github.com/<namespace>/<name> format.", source.String())
+	}
+
+	if parts[0] != defaultHostname {
+		return nil, fmt.Errorf("%q doesn't appear to be a valid %q source address; check source and try again.", source.String(), defaultHostname)
+	}
+
+	return &GithubPlugin{
+		Hostname:  parts[0],
+		Namespace: parts[1],
+		Type:      strings.Replace(parts[2], "packer-plugin-", "", 1),
+	}, nil
+}
+
+func (gp GithubPlugin) RealRelativePath() string {
+	return path.Join(
+		gp.Namespace,
+		fmt.Sprintf("packer-plugin-%s", gp.Type),
+	)
+}
+
+func (gp GithubPlugin) PluginType() string {
+	return fmt.Sprintf("packer-plugin-%s", gp.Type)
+}
+
 func (g *Getter) Get(what string, opts plugingetter.GetOptions) (io.ReadCloser, error) {
-	if opts.PluginRequirement.Identifier.Hostname != defaultHostname {
-		s := opts.PluginRequirement.Identifier.String() + " doesn't appear to be a valid " + defaultHostname + " source address; check source and try again."
-		return nil, errors.New(s)
+	log.Printf("[TRACE] Getting %s of %s plugin from %s", what, opts.PluginRequirement.Identifier, g.Name)
+	ghURI, err := NewGithubPlugin(opts.PluginRequirement.Identifier)
+	if err != nil {
+		return nil, err
 	}
 
 	ctx := context.TODO()
@@ -188,27 +236,26 @@ func (g *Getter) Get(what string, opts plugingetter.GetOptions) (io.ReadCloser,
 	}
 
 	var req *http.Request
-	var err error
 	transform := func(in io.ReadCloser) (io.ReadCloser, error) {
 		return in, nil
 	}
 
 	switch what {
 	case "releases":
-		u := filepath.ToSlash("/repos/" + opts.PluginRequirement.Identifier.RealRelativePath() + "/git/matching-refs/tags")
+		u := filepath.ToSlash("/repos/" + ghURI.RealRelativePath() + "/git/matching-refs/tags")
 		req, err = g.Client.NewRequest("GET", u, nil)
 		transform = transformVersionStream
 	case "sha256":
 		// something like https://github.com/sylviamoss/packer-plugin-comment/releases/download/v0.2.11/packer-plugin-comment_v0.2.11_x5_SHA256SUMS
-		u := filepath.ToSlash("https://github.com/" + opts.PluginRequirement.Identifier.RealRelativePath() + "/releases/download/" + opts.Version() + "/" + opts.PluginRequirement.FilenamePrefix() + opts.Version() + "_SHA256SUMS")
+		u := filepath.ToSlash("https://github.com/" + ghURI.RealRelativePath() + "/releases/download/" + opts.Version() + "/" + opts.PluginRequirement.FilenamePrefix() + opts.Version() + "_SHA256SUMS")
 		req, err = g.Client.NewRequest(
 			"GET",
 			u,
 			nil,
 		)
-		transform = transformChecksumStream()
+		transform = TransformChecksumStream()
 	case "zip":
-		u := filepath.ToSlash("https://github.com/" + opts.PluginRequirement.Identifier.RealRelativePath() + "/releases/download/" + opts.Version() + "/" + opts.ExpectedZipFilename())
+		u := filepath.ToSlash("https://github.com/" + ghURI.RealRelativePath() + "/releases/download/" + opts.Version() + "/" + opts.ExpectedZipFilename())
 		req, err = g.Client.NewRequest(
 			"GET",
 			u,
@@ -246,3 +293,43 @@ func (g *Getter) Get(what string, opts plugingetter.GetOptions) (io.ReadCloser,
 
 	return transform(resp.Body)
 }
+
+// Init method: a file inside will look like so:
+//
+//	packer-plugin-comment_v0.2.12_x5.0_freebsd_amd64.zip
+func (g *Getter) Init(req *plugingetter.Requirement, entry *plugingetter.ChecksumFileEntry) error {
+	filename := entry.Filename
+	res := strings.TrimPrefix(filename, req.FilenamePrefix())
+	// res now looks like v0.2.12_x5.0_freebsd_amd64.zip
+
+	entry.Ext = filepath.Ext(res)
+
+	res = strings.TrimSuffix(res, entry.Ext)
+	// res now looks like v0.2.12_x5.0_freebsd_amd64
+
+	parts := strings.Split(res, "_")
+	// ["v0.2.12", "x5.0", "freebsd", "amd64"]
+	if len(parts) < 4 {
+		return fmt.Errorf("malformed filename expected %s{version}_x{protocol-version}_{os}_{arch}", req.FilenamePrefix())
+	}
+
+	entry.BinVersion, entry.ProtVersion, entry.Os, entry.Arch = parts[0], parts[1], parts[2], parts[3]
+
+	return nil
+}
+
+func (g *Getter) Validate(opt plugingetter.GetOptions, expectedVersion string, installOpts plugingetter.BinaryInstallationOptions, entry *plugingetter.ChecksumFileEntry) error {
+	expectedBinVersion := "v" + expectedVersion
+	if entry.BinVersion != expectedBinVersion {
+		return fmt.Errorf("wrong version: %s does not match expected %s", entry.BinVersion, expectedBinVersion)
+	}
+	if entry.Os != installOpts.OS || entry.Arch != installOpts.ARCH {
+		return fmt.Errorf("wrong system, expected %s_%s", installOpts.OS, installOpts.ARCH)
+	}
+
+	return installOpts.CheckProtocolVersion(entry.ProtVersion)
+}
+
+func (g *Getter) ExpectedFileName(pr *plugingetter.Requirement, version string, entry *plugingetter.ChecksumFileEntry, zipFileName string) string {
+	return zipFileName
+}
